==========
Heading1
==========

:Date: Today
:Author: SpamEgg
:Location: Here

Heading2
==========

Heading3
----------

Heading4
^^^^^^^^^^

*emphasized* (e.g., italics)

**strongly emphasized** (e.g., boldface)

- An item in a bulleted (unordered) list

- Another item in a bulleted list

  - Second Level

  * Second Level Items

    * Third level

#. An item in an enumerated (ordered) list xxxxxxx

#. Another item in an enumerated list yyyyyy

   #. Another level in an enumerated list vvvvvvvv


Blockquotes

   This text will be enclosed in an HTML blockquote element.

   Second Paragraph.

Links

   `link text <link_address>`_

Images

    .. image:: imageurl


